---
html_theme.sidebar_secondary.remove:
---

# Timestream

```{eval-rst}
.. currentmodule:: kaskada

.. autoclass:: kaskada.Timestream
    :exclude-members: __init__

    .. autoproperty:: data_type

.. autoclass:: kaskada.Arg
.. autoclass:: kaskada.LiteralValue
```

```{toctree}
:hidden:

aggregation
arithmetic
collection
comparison
execution
grouping
logical
misc
records
string
time
```